==> haskell-aeson-compat-0.3.9-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-4JLfaSQqvdcCltTZVCb6k9
key: aeson-compat-0.3.9-4JLfaSQqvdcCltTZVCb6k9
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: 3018a712267b884f1ecd678b7fab06b9
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.1/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-4JLfaSQqvdcCltTZVCb6k9
depends:
    aeson-1.4.1.0-GPncuQLCkBq39NZScMfTsF
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI
    attoparsec-iso8601-1.0.1.0-H6kRr6PRuNJAFxxyoNfeHx base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-2Qg8WlJf6PLET7HqXRUMwz
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.9-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-2OBMCUhPLgFnwVuJIEBBR
key: aeson-compat-0.3.9-2OBMCUhPLgFnwVuJIEBBR
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: 494d6949573100b05b452216f77bb8a2
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.2/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.2/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-2OBMCUhPLgFnwVuJIEBBR
depends:
    aeson-1.4.1.0-LhGJkSbQXa4Bc1ggOsS4Ag
    attoparsec-0.13.2.2-CmkmuzHxC7WKLrfPgrn9Wq
    attoparsec-iso8601-1.0.1.0-5V4lFLkNnLmAjlnsLBRUzM base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.0-9c5BjQipUdiGeORB8copQH
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
